@@ -751,7 +751,7 @@ main (int     argc,
 	    break;
 
 	case 'c':
-            if (flags & FLAGS_MTIME == FLAGS_MTIME) {
+            if ((flags & FLAGS_MTIME) == FLAGS_MTIME) {
                 message(LOG_FATAL, "--ctime conflicts with --mtime option\n");
                 /*NOTREACHED*/
             }
@@ -759,7 +759,7 @@ main (int     argc,
 	    break;
 
 	case 'm':
-            if (flags & FLAGS_CTIME == FLAGS_CTIME) {
+            if ((flags & FLAGS_CTIME) == FLAGS_CTIME) {
                 message(LOG_FATAL, "--mtime conflicts with --ctime option\n");
                 /*NOTREACHED*/
             }
